# Copyright (C) 2015 Chi-kwan Chan
# Copyright (C) 2015 Steward Observatory
#
# This file is part of mockservation.
#
# Mockservation is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Mockservation is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with mockservation.  If not, see <http://www.gnu.org/licenses/>.

from os import path
from .  import hdf5

def dump(name, imgs=None, time=None, side=[], paras={}):
    if imgs is None or time is None:
        hdf5.update(name, paras)
        return

    if imgs.ndim != 3 or time.ndim != 1:
        raise NameError("Unexpected number of dimensions")
    if imgs.shape[1] != imgs.shape[2]:
        raise NameError("The images are not square")
    if imgs.shape[0] != time.shape[0]:
        raise NameError("The number of elements of time does not match "
                        "the zeroth dimension of imgs")

    ext = path.splitext(name)[1][1:]
    if ext == "h5" or ext == "hdf5":
        if path.isfile(name):
            hdf5.append(name, imgs, time)
        elif side != [] and paras != {}:
            hdf5.dump(name, imgs, time, side, paras)
        else:
            raise NameError("Variables nu and side are required "
                            "only for creating dump new HDF5 file")
    else:
        raise NameError("Fail to dump file \"{0}\", "
                        "which is in an unsupported format".format(name))
