# Copyright (C) 2015 Chi-kwan Chan
# Copyright (C) 2015 Steward Observatory
#
# This file is part of mockservation.
#
# Mockservation is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Mockservation is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with mockservation.  If not, see <http://www.gnu.org/licenses/>.

import h5py as h5

def dump(name, imgs, time, side, paras):
    """ Dump GRay data into a new HDF5 file """
    with h5.File(name, "w") as file: # FIXME: will file close automatically?
        print("Dumping GRay HDF5 file \"{0}\"".format(name))

        # Turn parameters into file attributes
        for key, value in paras.items():
            file.attrs[key] = value

        # Create image array/dataset
        maxs = (None, imgs.shape[1], imgs.shape[2])
        imgs = file.create_dataset("images", data=imgs,
                                   maxshape=maxs, chunks=(1, 64, 64))
        imgs.dims[0].label = "time"
        imgs.dims[1].label = "beta"
        imgs.dims[2].label = "alpha"

        # Create dimension scales
        time = file.create_dataset("time", data=time,
                                   maxshape=(None,), chunks=True)
        side = file.create_dataset("side", data=side)
        imgs.dims.create_scale(time)
        imgs.dims.create_scale(side)

        # Attach dimension scales to image array/dataset
        imgs.dims[0].attach_scale(time)
        imgs.dims[1].attach_scale(side)
        imgs.dims[2].attach_scale(side)
